@@ -155,8 +155,8 @@ class GameViewer(Canvas):
     @memoized
     def _get_image(self, name):
         """ Return (PIL.)Image instance. """
-        path = '../graphic/%s.png' % name
-        image = Image.open(path)
+        path = 'graphic/%s.png' % name
+        image = Image.open(datafile_path(path))
         return image
 
     def _get_scaled_sprite(self, name):
@@ -170,7 +170,8 @@ class GameViewer(Canvas):
         # otherwise compute, cache and return
         image = self._get_image(name)
         width, height = 256, 288
-        new_width, new_height = width*self._zoom+2, height*self._zoom+2
+        new_width, new_height = (int(width*self._zoom+2),
+                                 int(height*self._zoom+2))
         image = image.resize((new_width, new_height), Image.NEAREST)
         image = ImageTk.PhotoImage(image)
 
@@ -304,7 +305,7 @@ class ClientApplication(Frame):
         print os.getcwd()
 
         # load game and add player
-        stream = open('../maps/default.map', 'r')
+        stream = open(datafile_path('maps/default.map'), 'r')
         game_map = pickle.load(stream)
         stream.close()
         game = Game(game_map, DEFAULT_GAME_CONFIGURATION)
@@ -312,7 +313,7 @@ class ClientApplication(Frame):
 
         # set programs
         def set_program(id, filename):
-            code = open('./.tmp/'+filename, 'r').read()
+            code = open(datafile_path('.tmp/'+filename), 'r').read()
             program = Program(language=DEFAULT_PYTHON_LANGUAGE,
                               code=code)
             game.set_program(game.units_by_IDs[id], program)
